# Annnie File

An all-in-one package for connecting to an LLM (Large Language Model) to ask questions directly within the Vivado IDE.

## Installation

To install this package, use pip:

```sh
pip install annie_install

```
## System Dependencies

Before installing the Python package, you need to install some system-level dependencies. For Debian-based systems (like Ubuntu), you can use `apt-get`:

```sh
sudo apt-get update
sudo apt-get install python3-tk
```
